# app_booster/cli.py

import os
import sys
import subprocess
import shutil

def create_boosted_app(app_name):
    print(f" Création de l'app Django personnalisée : {app_name}")

    # Étape 1 : Créer app avec startapp
    subprocess.run(["django-admin", "startapp", app_name])

    if not os.path.exists(app_name):
        print("L'application n'a pas été créée.")
        sys.exit(1)

    # Étape 2 : Supprimer les fichiers à transformer en dossiers
    for file in ["views.py", "models.py", "tests.py"]:
        path = os.path.join(app_name, file)
        if os.path.exists(path):
            os.remove(path)

    # Étape 3 : Créer les dossiers avec __init__.py
    for folder in ["views", "models", "tests"]:
        folder_path = os.path.join(app_name, folder)
        os.makedirs(folder_path, exist_ok=True)
        open(os.path.join(folder_path, "__init__.py"), 'w').close()

    # Étape 4 : Créer fichier urls.py
    urls_content = """from django.urls import path

urlpatterns = [
    # Ajoutez vos vues ici
]
"""
    with open(os.path.join(app_name, "urls.py"), "w") as f:
        f.write(urls_content)

    print(f"App Django '{app_name}' créée avec : dossiers models/, views/, tests/ et fichier urls.py")

if __name__ == "__main__":
    if len(sys.argv) != 2:
        print("Utilisation : createapp <nom_app>")
        sys.exit(1)

    create_boosted_app(sys.argv[1])
